winnetwork

package module
v0.0.0-...-436d23d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 12, 2025 License: MIT Imports: 2 Imported by: 0

README

winnetwork Go Reference

The winnetwork package provides access to windows network management APIs.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddConnection

func AddConnection(local, remote string, persistent bool) (err error)

AddConnection attempts to map the given local name to a remote resource. If persistent is true it creates a persistent connection that survives logon/logoff cycles.

Connections are unique to each user.

func GetConnection

func GetConnection(local string) (remote string, err error)

GetConnection returns the remote resource for the local drive letter.

Connections are unique to each user.

func RemoveConnection

func RemoveConnection(name string, persistent, force bool) (err error)

RemoveConnection attempts to unmap the given local resource name that has previously been mapped to a remote resource.

If persistent is true, it permanently removes the connection from the user profile.

If force is true, it will forcefully close open files if necessary.

Connections are unique to each user.

Types

This section is empty.

Directories

Path Synopsis

Jump to