Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddConnection ¶
AddConnection attempts to map the given local name to a remote resource. If persistent is true it creates a persistent connection that survives logon/logoff cycles.
Connections are unique to each user.
func GetConnection ¶
GetConnection returns the remote resource for the local drive letter.
Connections are unique to each user.
func RemoveConnection ¶
RemoveConnection attempts to unmap the given local resource name that has previously been mapped to a remote resource.
If persistent is true, it permanently removes the connection from the user profile.
If force is true, it will forcefully close open files if necessary.
Connections are unique to each user.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.